@@ -30,7 +30,7 @@
  * <thomas.pornin@cryptolog.com>
  */
 
-#include "tomcrypt.h"
+#include "tomcrypt_private.h"
 
 #ifdef LTC_SOSEMANUK
 
@@ -201,7 +201,7 @@
  * @param keylen   Length of key in bytes
  * @return CRYPT_OK on success
  */
-int sosemanuk_setup(sosemanuk_state *ss, unsigned char *key, unsigned long keylen)
+int sosemanuk_setup(sosemanuk_state *ss, const unsigned char *key, unsigned long keylen)
 {
     /*
      * This key schedule is actually a truncated Serpent key schedule.
@@ -257,16 +257,12 @@ int sosemanuk_setup(sosemanuk_state *ss, unsigned char *key, unsigned long keyle
 
    LTC_ARGCHK(ss  != NULL);
    LTC_ARGCHK(key != NULL);
+   LTC_ARGCHK(keylen > 0 && keylen <= 32);
 
     /*
      * The key is copied into the wbuf[] buffer and padded to 256 bits
      * as described in the Serpent specification.
      */
-    if (keylen == 0 || keylen > 32) {
-        fprintf(stderr, "invalid key size: %lu\n",
-            (unsigned long)keylen);
-        exit(EXIT_FAILURE);
-    }
     XMEMCPY(wbuf, key, keylen);
     if (keylen < 32) {
         wbuf[keylen] = 0x01;
@@ -341,7 +337,7 @@ int sosemanuk_setup(sosemanuk_state *ss, unsigned char *key, unsigned long keyle
  * @param ivlen    Length of iv in bytes
  * @return CRYPT_OK on success
  */
-int sosemanuk_setiv(sosemanuk_state *ss, unsigned char *iv, unsigned long ivlen)
+int sosemanuk_setiv(sosemanuk_state *ss, const unsigned char *iv, unsigned long ivlen)
 {
 
     /*
